@@ -1,5 +1,5 @@
  /* OpenVAS
-  * $Id: comm.c 21992 2015-03-30 10:49:31Z kroosec $
+  * $Id: comm.c 23992 2015-12-16 23:40:29Z kroosec $
   * Description: Communication manager; it manages the NTP Protocol version 1.0 and 1.1.
   *
   * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -192,6 +192,12 @@ send_plug_info (int soc, struct arglist *plugins)
                  nvti_oid (nvti));
       ignored = 1;
     }
+  else if (strchr (name, '\n') != NULL)
+    {
+      log_write ("%s: Newline in name\n", nvti_oid (nvti));
+      ignored = 1;
+    }
+
 
   if ((copyright = nvti_copyright (nvti)) == NULL)
     {
@@ -226,13 +232,6 @@ send_plug_info (int soc, struct arglist *plugins)
       ignored = 1;
     }
 
-
-  if (strchr (name, '\n') != NULL)
-    {
-      log_write ("%s: Newline in name\n", nvti_oid (nvti));
-      ignored = 1;
-    }
-
   if (strchr (copyright, '\n') != NULL)
     {
       log_write ("%s: Newline in copyright\n", nvti_oid (nvti));
