@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: log.c 22376 2015-05-13 23:36:56Z kroosec $
+* $Id: log.c 25471 2016-06-09 00:54:05Z kroosec $
 * Description: Manages the logfile of OpenVAS.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -39,7 +39,7 @@
 #include "utils.h"
 #include "log.h"
 
-static FILE *log;
+static FILE *log = NULL;
 
 /**
  * @brief Initialization of the log file.
@@ -75,6 +75,16 @@ log_init (const char *filename)
 }
 
 
+/**
+ * @brief Get the open log file descriptor.
+ *
+ * @param[out]   Return the log file descriptor.
+ */
+int
+log_get_fd ()
+{
+  return log ? fileno (log) : -1;
+}
 
 void
 log_close ()
