@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: openvassd.c 22546 2015-06-02 15:21:47Z kroosec $
+* $Id: openvassd.c 25076 2016-04-25 12:49:37Z kroosec $
 * Description: Runs the OpenVAS-scanner.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -108,6 +108,7 @@ static openvassd_option openvassd_defaults[] = {
   {"network_scan", "no"},
   {"non_simult_ports", "139, 445"},
   {"plugins_timeout", G_STRINGIFY (NVT_TIMEOUT)},
+  {"scanner_plugins_timeout", G_STRINGIFY (SCANNER_NVT_TIMEOUT)},
   {"safe_checks", "yes"},
   {"auto_enable_dependencies", "yes"},
   {"use_mac_addr", "no"},
@@ -124,6 +125,7 @@ static openvassd_option openvassd_defaults[] = {
   {"key_file", SCANNERKEY},
   {"ca_file", CACERT},
   {"kb_location", KB_PATH_DEFAULT},
+  {"timeout_retry", "3"},
   {NULL, NULL}
 };
 
@@ -425,7 +427,11 @@ scanner_thread (struct arglist *globals)
   else
     {
       struct sockaddr_in6 *s6addr = (struct sockaddr_in6 *) &addr;
-      inet_ntop (AF_INET6, &s6addr->sin6_addr, asciiaddr, sizeof (asciiaddr));
+      if (IN6_IS_ADDR_V4MAPPED (&s6addr->sin6_addr))
+        inet_ntop (AF_INET, &s6addr->sin6_addr.s6_addr[12],
+                   asciiaddr, sizeof (asciiaddr));
+      else
+        inet_ntop (AF_INET6, &s6addr->sin6_addr, asciiaddr, sizeof (asciiaddr));
     }
   proctitle_set ("openvassd: Serving %s", asciiaddr);
 
