@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: pluginload.h 9967 2011-01-14 15:38:08Z jan $
+* $Id: pluginload.h 20867 2014-11-16 20:23:56Z jan $
 * Description: pluginload.c header.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -34,46 +34,31 @@
 #include <openvas/misc/arglists.h>   /* for struct arglist */
 #include <openvas/misc/kb.h>         /* for struct kb_item */
 
-struct arglist *plugins_init (struct arglist *, int);
-struct arglist *plugins_reload (struct arglist *, struct arglist *, int);
+struct arglist *plugins_init (void);
 void plugin_set_socket (struct arglist *, int);
 int plugin_get_socket (struct arglist *);
 void plugins_set_socket (struct arglist *, int);
 void plugin_free (struct arglist *);
 void plugins_free (struct arglist *);
 
+void
+init_loading_shm (void);
 
-/**
- * Plugin standard function template to init a plugin (nasl/nes/oval).
- */
-typedef int (*plugin_init_t) (struct arglist *);
-/**
- * Plugin standard function template to run a plugin (nasl/nes/oval).
- */
-typedef int (*plugin_run_t) (struct arglist *);
+void
+destroy_loading_shm (void);
 
+int
+current_loading_plugins (void);
 
-/**
- * Class of a NVT (implemented as list).
- * Currently two classes do exist: nasl_plugin_class and oval_plugin_class.
- * Holds the extension string and pointers to init, add and launch-functions.
- */
-typedef struct pl_class_s
-{
-    /** Pointer to next class in list. */
-  struct pl_class_s *pl_next;
-    /** File extension for this NVT class (e.g. ".nasl"). */
-  const char *extension;
-    /** Pointer to init function */
-  struct pl_class_s *(*pl_init) (struct arglist *, struct arglist *);
-    /** Pointer to add function */
-  struct arglist *(*pl_add) (char *, char *, struct arglist *,
-                             struct arglist *);
-    /** Pointer to launch function */
-  int (*pl_launch) (struct arglist *, struct arglist *, struct arglist *,
-                    struct arglist *, struct kb_item **, char *);
-} pl_class_t;
+int
+total_loading_plugins (void);
+
+/* From nasl_plugins.c */
+struct arglist *
+nasl_plugin_add (char *, char *, struct arglist *);
+
+int
+nasl_plugin_launch (struct arglist *, struct arglist *, struct arglist *,
+                    kb_t, char *, const char *);
 
-extern pl_class_t nasl_plugin_class;
-extern pl_class_t oval_plugin_class;
 #endif
