@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: plugs_req.c 9880 2011-01-04 18:04:48Z jan $
+* $Id: plugs_req.c 22004 2015-03-31 15:06:57Z kroosec $
 * Description: Performs various checks for requirements set in a given plugin.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -29,7 +29,7 @@
 #include <string.h> /* for strcmp() */
 #include <stdio.h>  /* for snprintf() */
 
-#include <openvas/misc/system.h>     /* for emalloc */
+#include <openvas/misc/prefs.h>          /* for prefs_get() */
 
 #include "pluginscheduler.h"
 #include "plugs_req.h"
@@ -40,8 +40,7 @@
 
 ***********************************************************/
 
-extern int kb_get_port_state_proto (struct kb_item **, struct arglist *, int,
-                                    char *);
+extern int kb_get_port_state_proto (kb_t, int, char *);
 
 /**
  * @brief Returns whether a port in a port list is closed or not.
@@ -49,26 +48,26 @@ extern int kb_get_port_state_proto (struct kb_item **, struct arglist *, int,
  * @return Whether a port in a port list is closed or not.
  */
 static int
-get_closed_ports (struct kb_item **kb, struct arglist *ports,
-                  struct arglist *preferences)
+get_closed_ports (kb_t kb, gchar **ports)
 {
+  int i;
+
   if (ports == NULL)
     return -1;
 
-  while (ports->next != NULL)
+  for (i = 0; ports[i] != NULL; i ++)
     {
-      int iport = atoi (ports->name);
+      int iport = atoi (ports[i]);
       if (iport != 0)
         {
-          if (kb_get_port_state_proto (kb, preferences, iport, "tcp") != 0)
+          if (kb_get_port_state_proto (kb, iport, "tcp") != 0)
             return iport;
         }
       else
         {
-          if (kb_item_get_int (kb, ports->name) > 0)
+          if (kb_item_get_int (kb, ports[i]) > 0)
             return 1;           /* should be the actual value indeed ! */
         }
-      ports = ports->next;
     }
   return 0;                     /* found nothing */
 }
@@ -78,65 +77,22 @@ get_closed_ports (struct kb_item **kb, struct arglist *ports,
  * @brief Returns whether a port in a port list is closed or not.
  */
 static int
-get_closed_udp_ports (struct kb_item **kb, struct arglist *ports,
-                      struct arglist *preferences)
+get_closed_udp_ports (kb_t kb, gchar **ports)
 {
+  int i;
+
   if (ports == NULL)
     return -1;
 
-  while (ports->next != NULL)
+  for (i = 0; ports[i] != NULL; i ++)
     {
-      int iport = atoi (ports->name);
-      if (kb_get_port_state_proto (kb, preferences, iport, "udp"))
+      int iport = atoi (ports[i]);
+      if (iport > 0 && kb_get_port_state_proto (kb, iport, "udp"))
         return iport;
-      ports = ports->next;
     }
   return 0;                     /* found nothing */
 }
 
-
-/**
- * @brief Returns the name of the first key which is not \ref kb.
- */
-static char *
-key_missing (struct kb_item **kb, struct arglist *keys)
-{
-  if (kb == NULL || keys == NULL)
-    return NULL;
-  else
-    {
-      while (keys->next != NULL)
-        {
-          if (kb_item_get_single (kb, keys->name, 0) == NULL)
-            return keys->name;
-          else
-            keys = keys->next;
-        }
-    }
-  return NULL;
-}
-
-/**
- * @brief The opposite of the previous function (\ref key_missing).
- */
-static char *
-key_present (struct kb_item **kb, struct arglist *keys)
-{
-  if (kb == NULL || keys == NULL)
-    return NULL;
-  else
-    {
-      while (keys->next != NULL)
-        {
-          if (kb_item_get_single (kb, keys->name, 0) != NULL)
-            return keys->name;
-          else
-            keys = keys->next;
-        }
-    }
-  return NULL;
-}
-
 /**********************************************************
 
  		   Public Functions
@@ -153,42 +109,93 @@ requirements_common_ports (struct scheduler_plugin *plugin1,
                            struct scheduler_plugin *plugin2)
 {
   struct arglist *ret = NULL;
-  struct arglist *req1;
-  struct arglist *req2;
+  int i, j;
 
   if (!plugin1 || !plugin2)
     return 0;
 
-  req1 = plugin1->required_ports;
-  if (req1 == NULL)
+  if (plugin1->required_ports == NULL)
     return 0;
 
-  req2 = plugin2->required_ports;
-  if (req2 == NULL)
+  if (plugin2->required_ports == NULL)
     return 0;
 
-  while (req1->next != NULL)
+  for (i = 0; plugin1->required_ports[i] != NULL; i ++)
     {
-      struct arglist *r = req2;
-      if (r != NULL)
-        while (r->next != NULL)
-          {
-            if (req1->type == r->type)
-              {
-                if (r->name && req1->name && !strcmp (r->name, req1->name))
-                  {
-                    if (!ret)
-                      ret = emalloc (sizeof (struct arglist));
-                    arg_add_value (ret, r->name, ARG_INT, 0, (void *) 1);
-                  }
-              }
-            r = r->next;
-          }
-      req1 = req1->next;
+      for (j = 0; plugin2->required_ports[j] != NULL; j ++)
+        {
+           if (!strcmp (plugin2->required_ports[j], plugin1->required_ports[i]))
+             {
+               if (!ret)
+                 ret = g_malloc0 (sizeof (struct arglist));
+               arg_add_value (ret, plugin2->required_ports[j], ARG_INT,
+                              (void *) 1);
+             }
+        }
     }
   return ret;
 }
 
+/**
+ * @brief Returns the name of the first key which is not present in the \ref kb.
+ * @param[in] kb       KB handle where to search for the keys.
+ * @param[in] keynames NULL-terminated string array of keynames.
+ * @return A pointer to the string that was not found in the kb. This pointer
+           points into the string in the given keynames array.
+           NULL is returned in case all of the keys are present in the kb or
+           the kb is NULL.
+ */
+static gchar *
+kb_missing_keyname_of_namelist (kb_t kb, gchar **keynames)
+{
+  int i;
+
+  if (kb == NULL || keynames == NULL)
+    return NULL;
+
+  for (i = 0; keynames[i] != NULL; i ++)
+    {
+      struct kb_item *kbi = kb_item_get_single (kb, keynames[i], KB_TYPE_UNSPEC);
+
+      if (kbi == NULL)
+        return keynames[i]; /* This key is missing in the kb */
+
+      kb_item_free (kbi);
+    }
+
+  return NULL; /* All of the keys are present in the kb */
+}
+
+/**
+ * @brief Returns the name of the first key which is present in the \ref kb.
+ * @param[in] kb       KB handle where to search for the keys.
+ * @param[in] keynames NULL-terminated string array of keynames.
+ * @return A pointer to the string that was found in the kb. This pointer
+           points into the string in the given keynames array.
+           NULL is returned in case none of the keys is present in the kb or
+           the kb is NULL.
+ */
+static gchar *
+kb_present_keyname_of_namelist (kb_t kb, gchar **keynames)
+{
+  int i;
+
+  if (kb == NULL || keynames == NULL)
+    return NULL;
+
+  for (i = 0; keynames[i] != NULL; i ++)
+    {
+      struct kb_item *kbi = kb_item_get_single (kb, keynames[i], KB_TYPE_UNSPEC);
+
+      if (kbi != NULL)
+        {
+          kb_item_free (kbi);
+          return keynames[i];
+        }
+    }
+  return NULL;
+}
+
 /**
  * @brief Check whether mandatory requirements for plugin are met.
  *
@@ -200,10 +207,10 @@ requirements_common_ports (struct scheduler_plugin *plugin1,
  *         met. 0 if it is not the case.
  */
 int
-mandatory_requirements_met (struct kb_item **kb,
+mandatory_requirements_met (kb_t kb,
                             struct scheduler_plugin *plugin)
 {
-  if (key_missing (kb, plugin->mandatory_keys))
+  if (kb_missing_keyname_of_namelist (kb, plugin->mandatory_keys))
     return 0;
 
   return 1;
@@ -215,21 +222,20 @@ mandatory_requirements_met (struct kb_item **kb,
  * @return Returns NULL is everything is ok, else an error message.
  */
 char *
-requirements_plugin (struct kb_item **kb, struct scheduler_plugin *plugin,
-                     struct arglist *preferences)
+requirements_plugin (kb_t kb, struct scheduler_plugin *plugin)
 {
   static char error[64];
   char *missing;
   char *present;
-  struct arglist *tcp, *udp, *rkeys, *ekeys;
-  char *opti = arg_get_value (preferences, "optimization_level");
+  gchar **tcp, **udp;
+  const char *opti = prefs_get ("optimization_level");
 
   /*
    * Check wether the good ports are open
    */
   error[sizeof (error) - 1] = '\0';
   tcp = plugin->required_ports;
-  if (tcp != NULL && (get_closed_ports (kb, tcp, preferences)) == 0)
+  if (tcp != NULL && (get_closed_ports (kb, tcp)) == 0)
     {
       strncpy (error, "none of the required tcp ports are open",
                sizeof (error) - 1);
@@ -237,7 +243,7 @@ requirements_plugin (struct kb_item **kb, struct scheduler_plugin *plugin,
     }
 
   udp = plugin->required_udp_ports;
-  if (udp != NULL && (get_closed_udp_ports (kb, udp, preferences)) == 0)
+  if (udp != NULL && (get_closed_udp_ports (kb, udp)) == 0)
     {
       strncpy (error, "none of the required udp ports are open",
                sizeof (error) - 1);
@@ -250,8 +256,7 @@ requirements_plugin (struct kb_item **kb, struct scheduler_plugin *plugin,
   /*
    * Check wether a key we wanted is missing
    */
-  rkeys = plugin->required_keys;
-  if ((missing = key_missing (kb, rkeys)))
+  if ((missing = kb_missing_keyname_of_namelist (kb, plugin->required_keys)))
     {
       snprintf (error, sizeof (error), "because the key %s is missing",
                 missing);
@@ -264,8 +269,7 @@ requirements_plugin (struct kb_item **kb, struct scheduler_plugin *plugin,
   /*
    * Check wether a key we do not want is present
    */
-  ekeys = plugin->excluded_keys;
-  if ((present = key_present (kb, ekeys)))
+  if ((present = kb_present_keyname_of_namelist (kb, plugin->excluded_keys)))
     {
       snprintf (error, sizeof (error), "because the key %s is present",
                 present);
