@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: sighand.c 21730 2015-02-27 14:49:27Z kroosec $
+* $Id: sighand.c 25860 2016-07-28 14:16:57Z mattm $
 * Description: Provides signal handling functions.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -35,6 +35,7 @@
 #include "log.h"
 #include "sighand.h"
 #include "utils.h"
+#include "string.h"
 
 #include <openvas/base/pidfile.h>
 
@@ -116,24 +117,38 @@ static void
 print_trace ()
 {
   void *array[10];
-  size_t size;
-  char **symbols;
-  size_t i;
+  int fd, ret = 0, left;
+  char *message = "SIGSEGV occured !\n";
 
-  size = backtrace (array, 10);
-  symbols = backtrace_symbols (array, size);
-  for (i = 0; i < size; i++)
-     log_write ("%s\n", symbols[i]);
-  g_free (symbols);
+  fd = log_get_fd ();
+  if (fd < 0)
+    return;
+
+  left = strlen (message);
+  while (left)
+    {
+      ret = write (fd, message, left);
+      if (ret == -1)
+        {
+          if (errno == EINTR || errno == EAGAIN || errno == EWOULDBLOCK)
+            continue;
+          break;
+        }
+      left -= ret;
+      message += ret;
+    }
+  ret = backtrace (array, 10);
+  backtrace_symbols_fd (array, ret, fd);
 }
 
 void
-sighand_segv ()
+sighand_segv (int given_signal)
 {
   signal (SIGSEGV, _exit);
-  log_write ("SIGSEGV occured !");
   print_trace ();
   make_em_die (SIGTERM);
-  log_close ();
-  _exit (0);
+  /* Raise signal again, to exit with the correct return value,
+   * and to enable core dumping. */
+  openvas_signal (given_signal, SIG_DFL);
+  raise (given_signal);
 }
